diff --git a/tracing/examples/grpc/main.go b/tracing/examples/grpc/main.go
index cd6be0a..d1e82e3 100644
--- a/tracing/examples/grpc/main.go
+++ b/tracing/examples/grpc/main.go
@@ -82,7 +82,7 @@ func main() {
 	cc, err := grpc.NewClient(":7000",
 		grpc.WithTransportCredentials(insecure.NewCredentials()),
 		grpc.WithChainUnaryInterceptor(
-			tracing_grpc.NewUnaryClientInteceptor(),
+			tracing_grpc.NewUnaryClientInterceptor(),
 			verifyClientTraceID,
 		),
 		grpc.WithChainStreamInterceptor(
diff --git a/tracing/grpc/interceptors.go b/tracing/grpc/interceptors.go
index 21eeaf5..cb84162 100644
--- a/tracing/grpc/interceptors.go
+++ b/tracing/grpc/interceptors.go
@@ -15,8 +15,8 @@ import (
 	"google.golang.org/grpc/status"
 )
 
-// NewUnaryClientInteceptor creates new gRPC unary interceptor to save gRPC client traces.
-func NewUnaryClientInteceptor() grpc.UnaryClientInterceptor {
+// NewUnaryClientInterceptor creates new gRPC unary interceptor to save gRPC client traces.
+func NewUnaryClientInterceptor() grpc.UnaryClientInterceptor {
 	return func(ctx context.Context, method string, req, reply any, cc *grpc.ClientConn, invoker grpc.UnaryInvoker, opts ...grpc.CallOption) error {
 		ctx, span := startClientSpan(ctx, cc, method)
 		defer span.End()